<?php

namespace Guru\PushPostback\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Guru\PushPostback\Interfaces\PushPostbackRepositoryInterface;
use Guru\PushPostback\Repositories\Presenter\PushPostbackItemTransformer;

/**
 * Pubic API controller class.
 */
class PushPostbackPublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Guru\PushPostback\Interfaces\PushPostbackRepositoryInterface $push_postback
     *
     * @return type
     */
    public function __construct(PushPostbackRepositoryInterface $push_postback)
    {
        $this->repository = $push_postback;
        parent::__construct();
    }

    /**
     * Show push_postback's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $push_postbacks = $this->repository
            ->setPresenter('\\Guru\\PushPostback\\Repositories\\Presenter\\PushPostbackListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $push_postbacks['code'] = 2000;
        return response()->json($push_postbacks)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show push_postback.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $push_postback = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($push_postback)) {
            $push_postback         = $this->itemPresenter($module, new PushPostbackItemTransformer);
            $push_postback['code'] = 2001;
            return response()->json($push_postback)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
