<?php

namespace Guru\PushPostback\Providers;

use Illuminate\Support\ServiceProvider;

class PushPostbackServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'push_postback');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'push_postback');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('push_postback', function ($app) {
            return $this->app->make('Guru\PushPostback\PushPostback');
        });

        // Bind PushPostback to repository
        $this->app->bind(
            \Guru\PushPostback\Interfaces\PushPostbackRepositoryInterface::class,
            \Guru\PushPostback\Repositories\Eloquent\PushPostbackRepository::class
        );

        $this->app->register(\Guru\PushPostback\Providers\AuthServiceProvider::class);
        $this->app->register(\Guru\PushPostback\Providers\EventServiceProvider::class);
        $this->app->register(\Guru\PushPostback\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['push_postback'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/push_postback.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/push_postback')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/push_postback')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
